@@ -10,7 +10,8 @@ EXPECTED_TF_CONFIG_FILE_NAMES = ["tdfconfig.yml", "tdfconfig.yaml", "validate_co
 TRANSFORM_API_URL = "https://web-api.prod.transformdata.io"
 UPLOAD_MODE_VALIDATE = "validate"
 UPLOAD_MODE_COMMIT = "commit"
-
+# TODO: Return error response so this constant doesn't have to be passed to the CLI
+ERROR_RESPONSE_PREFIX = "Error response: "
 
 logger = logging.getLogger(__name__)
 
@@ -35,9 +36,11 @@ def read_config_files(config_dir: str):
                 try:
                     yaml.safe_load_all(results[filepath])
                 except yaml.parser.ParserError as e:
-                    raise yaml.parser.ParserError(f"Invalid yaml in config file at path: {filepath}. Exception: '{e}'")
+                    raise yaml.parser.ParserError(
+                        f"Invalid yaml in config file at path: {filepath}. {ERROR_RESPONSE_PREFIX}'{e}'"
+                    )
                 except Exception as e:
-                    raise Exception(f"Failed loading yaml config file. Error {e}")
+                    raise Exception(f"Failed loading yaml config file. {ERROR_RESPONSE_PREFIX}{e}")
 
                 results[fname] = f.read()
 
@@ -65,7 +68,7 @@ def upload_configs(  # noqa: D
     logger.info("Uploading config files")
     r = requests.post(add_files_url, data=json.dumps(results).encode("utf-8"), headers=headers, verify=verify)
     if r.status_code != 200:
-        raise Exception(f"Failed uploading config yaml files. Error: {r.text}")
+        raise Exception(f"Failed uploading config yaml files. {ERROR_RESPONSE_PREFIX}{r.text}")
 
     if mode == UPLOAD_MODE_VALIDATE:
         validate_url = f"{url}/api/v1/model/{repo}/{branch}/{commit}/validate_model"
@@ -73,7 +76,7 @@ def upload_configs(  # noqa: D
         logger.info("Checking that uploaded configs are valid and form a valid model")
         r = requests.post(validate_url, headers=headers, verify=verify)
         if r.status_code != 200:
-            raise Exception(f"Failed validating uploaded configs. Error response: {r.text}")
+            raise Exception(f"{ERROR_RESPONSE_PREFIX}{r.text}")
         logger.info("Successfully validated configs")
     elif mode == UPLOAD_MODE_COMMIT:
         commit_url = f"{url}/api/v1/model/{repo}/{branch}/{commit}/commit_model"
@@ -81,7 +84,7 @@ def upload_configs(  # noqa: D
         logger.info("Committing model")
         r = requests.post(commit_url, headers=headers, verify=verify)
         if r.status_code != 200:
-            raise Exception(f"Failed committing uploaded configs. Error response: {r.text}")
+            raise Exception(f"{ERROR_RESPONSE_PREFIX}{r.text}")
         logger.info("Successfully committed configs")
     else:
         raise ValueError(f"Invalid upload mode ({mode}). Expected '{UPLOAD_MODE_VALIDATE}' or '{UPLOAD_MODE_COMMIT}'")
